use tui::{
    backend::Backend,
    layout::{Layout, Direction, Constraint, Rect},
    widgets::{Paragraph, Block, Borders, Clear},
    Frame,
};

use crate::app::SuteState;

pub fn draw_ui<B: Backend>(f: &mut Frame<B>, app: &mut SuteState) {
    let outer_layout = Layout::default()
        .direction(Direction::Vertical)
        .constraints([
                Constraint::Length(6),
                Constraint::Min(1),
                Constraint::Length(3),
            ].as_ref(),
        )
        .split(f.size());


    draw_header(f, app, outer_layout[0]);
    draw_main(f, app, outer_layout[1]);
    draw_command_line(f, app, outer_layout[2]);
}

fn draw_header<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
    f.render_widget(Block::default()
        .title("Status")
        .borders(Borders::ALL), layout_chunk);
}

fn draw_main<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
   // let chunk = Layout::default()
   //     .direction(Direction::Horizontal)
   //     .constraints([Constraint::Percentage(20), Constraint::Percentage(80)].as_ref())
   //     .split(layout_chunk);

    draw_logs(f, app, layout_chunk)
}
fn draw_logs<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
    // TODO: Just use a signal.
    let v = app.log.get_inner().clone();
    f.render_widget(Paragraph::new(v.into_iter().collect::<Vec<tui::text::Spans>>()), layout_chunk);
}

fn draw_command_line<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
    let block = Block::default()
        .title("Command line")
        .borders(Borders::ALL);
    let inner_rect = block.inner(layout_chunk);

    f.render_widget(block, layout_chunk);

    let cmdline = format!("{} > {}", app.tick_c, app.cmd_line);
    f.render_widget(Paragraph::new(&cmdline[..]), inner_rect);
}
